@@ -27,10 +27,8 @@
 
 #include <kcombobox.h>
 #include <KLocalizedString>
-#include <kpassworddialog.h>
 
 #include <QCheckBox>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -45,8 +43,8 @@ FeedPropertiesWidget::FeedPropertiesWidget(QWidget *parent, const QString &name)
     connect(cb_updateInterval, &QCheckBox::toggled, updateComboBox, &KComboBox::setEnabled);
     connect(cb_updateInterval, &QCheckBox::toggled, updateLabel, &QLabel::setEnabled);
     connect(cb_updateInterval, &QCheckBox::toggled, this, &FeedPropertiesWidget::slotUpdateCheckBoxToggled);
-    connect(updateComboBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &FeedPropertiesWidget::slotUpdateComboBoxActivated);
-    connect(updateSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &FeedPropertiesWidget::slotUpdateComboBoxLabels);
+    connect(updateComboBox, QOverload<int>::of(&KComboBox::activated), this, &FeedPropertiesWidget::slotUpdateComboBoxActivated);
+    connect(updateSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &FeedPropertiesWidget::slotUpdateComboBoxLabels);
     connect(rb_limitArticleAge, &QRadioButton::toggled, sb_maxArticleAge, &KPluralHandlingSpinBox::setEnabled);
     connect(rb_limitArticleNumber, &QRadioButton::toggled, sb_maxArticleNumber, &KPluralHandlingSpinBox::setEnabled);
 }
@@ -78,13 +76,13 @@ FeedPropertiesDialog::FeedPropertiesDialog(QWidget *parent, const QString &name)
 {
     setObjectName(name);
     setWindowTitle(i18n("Feed Properties"));
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     widget = new FeedPropertiesWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
-    okButton->setDefault(true);
-    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    mOkButton = buttonBox->button(QDialogButtonBox::Ok);
+    mOkButton->setDefault(true);
+    mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &FeedPropertiesDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &FeedPropertiesDialog::reject);
     buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
@@ -133,6 +131,7 @@ void FeedPropertiesDialog::slotSetWindowTitle(const QString &title)
 {
     setWindowTitle(title.isEmpty() ? i18n("Feed Properties")
                    : i18n("Properties of %1", title));
+    mOkButton->setEnabled(!title.trimmed().isEmpty());
 }
 
 void FeedPropertiesDialog::setFeed(Feed *feed)
